pub struct RingbufRw<'a> { /* private fields */ }Implementations
Sourceimpl<'a> RingbufRw<'a>
impl<'a> RingbufRw<'a>
pub fn make(tail: &'a mut usize, head: &'a usize, buffer: &'a mut [u8]) -> Self
Sourcepub unsafe fn new(size: usize, data: *mut u8) -> Self
pub unsafe fn new(size: usize, data: *mut u8) -> Self
Safety
This function is used to create a ringbuffer from a pointer and length It is up to the caller to ensure the size argument is correct
pub fn is_empty(&self) -> bool
pub fn is_full(&self) -> bool
pub fn get_curr_bytes(&self) -> usize
pub fn get_head(&self) -> usize
pub fn get_tail(&self) -> usize
pub fn set_tail(&mut self, num: usize)
pub fn get_size(&self) -> usize
pub fn empty_slots_left(&self) -> usize
pub fn push(&mut self, msg: &[u8]) -> usize